Investigation
-------------

There are two most famous chat protocols: `XMPP <http://en.wikipedia.org/wiki/XMPP/>`_ (Extensible Messaging and 
Presence Protocol) and `IRC <http://en.wikipedia.org/wiki/Internet_Relay_Chat/>`_ (Internet Relay Chat). All those
protocols are complicated and illustrate how interlocutors connect with each other by using pull of servers with secure 
and safe way. They are solved multi users and multi server collisions.

SFChat does not has such problems because only one server and only two users are involved to message change process.
Therefore it’s efficient to create new protocol for SFChat.
